@@ -1,10 +1,11 @@
+# -*- coding: utf-8 -*-
 import os
 import re
-import shutil
-import six
 import sys
+import shutil
 
-from nose.tools import ok_, raises
+import six
+from nose.tools import ok_, raises, assert_raises
 from fudge import patched_context, with_fakes, Fake
 from fudge.inspector import arg as fudge_arg
 from mock_streams import mock_streams
@@ -232,23 +233,24 @@ def test_sudo_prefix_with_user_and_group():
     )
 
 
-@with_settings(use_shell=True)
 def test_shell_wrap():
     prefix = "prefix"
     command = "command"
-    for description, shell, sudo_prefix, result in (
-        ("shell=True, sudo_prefix=None",
-            True, None, '%s "%s"' % (env.shell, command)),
-        ("shell=True, sudo_prefix=string",
-            True, prefix, prefix + ' %s "%s"' % (env.shell, command)),
-        ("shell=False, sudo_prefix=None",
-            False, None, command),
-        ("shell=False, sudo_prefix=string",
-            False, prefix, prefix + " " + command),
-    ):
-        eq_.description = "_shell_wrap: %s" % description
-        yield eq_, _shell_wrap(command, shell_escape=True, shell=shell, sudo_prefix=sudo_prefix), result
-        del eq_.description
+    for shell, sudo_prefix, result in [
+        (True, None, '%s "%s"' % (env.shell, command)),
+        (True, prefix, prefix + ' %s "%s"' % (env.shell, command)),
+        (False, None, command),
+        (False, prefix, prefix + " " + command),
+    ]:
+        with settings(use_shell=True):
+            def case():
+                eq_(
+                    _shell_wrap(command, shell_escape=True, shell=shell, sudo_prefix=sudo_prefix),
+                    result
+                )
+
+            case.description = "_shell_wrap: shell=%s sudo_prefix=%s" % (shell, sudo_prefix)
+            yield case
 
 
 @with_settings(use_shell=True)
@@ -1099,21 +1101,37 @@ def test_local_output_and_capture():
         for stdout in (True, False):
             for stderr in (True, False):
                 hides, shows = ['running'], []
-                if stdout:
-                    hides.append('stdout')
-                else:
-                    shows.append('stdout')
-                if stderr:
-                    hides.append('stderr')
-                else:
-                    shows.append('stderr')
+                (hides if stdout else shows).append('stdout')
+                (hides if stderr else shows).append('stderr')
+
                 with nested(hide(*hides), show(*shows)):
-                    d = "local(): capture: %r, stdout: %r, stderr: %r" % (
+                    def case():
+                        local("echo 'foo' >/dev/null", capture)
+
+                    case.description = "local(): capture=%r, stdout=%r, stderr=%r" % (
                         capture, stdout, stderr
                     )
-                    local.description = d
-                    yield local, "echo 'foo' >/dev/null", capture
-                    del local.description
+                    yield case
+
+def test_local_captured_error_includes_output():
+    with assert_raises(SystemExit) as cm:
+        # list something that will exist '/' along with something that won't
+        # so that we will have output in stdout as well as stderr
+        local('ls / thisfiledoesnotexist', capture=True)
+    ex = cm.exception
+    assert_contains('Standard output', ex.message)
+    assert_contains('Standard error', ex.message)
+
+def test_local_encoding():
+    for octstr, encoding, expected in [
+        (r"t\303\251\303\274\303\242s", 'utf-8', u"téüâs"),
+        (r"t\351\374\342s", 'latin1', u"téüâs"),
+        (r"a\001\002\003", 'binary', b"a\x01\x02\x03"),
+    ]:
+        res = local("printf '%s'" % octstr, capture=True, encoding=encoding)
+        if six.PY2 and encoding != "binary":
+            res = res.decode(encoding)
+        assert res == expected, "%r != %r" % (res, expected)
 
 
 class TestRunSudoReturnValues(FabricTest):
